# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: messages.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'messages.proto'
)
# @@protoc_insertion_point(imports)

from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2

_sym_db = _symbol_database.Default()
_sym_db.RegisterFileDescriptor(google_dot_protobuf_dot_struct__pb2.DESCRIPTOR)




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0emessages.proto\x12\x0frappel.messages\x1a\x1cgoogle/protobuf/struct.proto\"r\n\x08\x45nvelope\x12\x13\n\x0b\x64\x65livery_id\x18\x01 \x01(\x04\x12\x14\n\x0cpartition_id\x18\x02 \x01(\r\x12*\n\x04kind\x18\x03 \x01(\x0e\x32\x1c.rappel.messages.MessageKind\x12\x0f\n\x07payload\x18\x04 \x01(\x0c\"\xbf\x02\n\x0e\x41\x63tionDispatch\x12\x11\n\taction_id\x18\x01 \x01(\t\x12\x13\n\x0binstance_id\x18\x02 \x01(\t\x12\x10\n\x08sequence\x18\x03 \x01(\r\x12\x37\n\x08\x64ispatch\x18\x04 \x01(\x0b\x32%.rappel.messages.WorkflowNodeDispatch\x12\x1c\n\x0ftimeout_seconds\x18\x05 \x01(\rH\x00\x88\x01\x01\x12\x18\n\x0bmax_retries\x18\x06 \x01(\rH\x01\x88\x01\x01\x12\x1b\n\x0e\x61ttempt_number\x18\x07 \x01(\rH\x02\x88\x01\x01\x12\x1b\n\x0e\x64ispatch_token\x18\x08 \x01(\tH\x03\x88\x01\x01\x42\x12\n\x10_timeout_secondsB\x0e\n\x0c_max_retriesB\x11\n\x0f_attempt_numberB\x11\n\x0f_dispatch_token\"\x8f\x02\n\x0c\x41\x63tionResult\x12\x11\n\taction_id\x18\x01 \x01(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x33\n\x07payload\x18\x03 \x01(\x0b\x32\".rappel.messages.WorkflowArguments\x12\x17\n\x0fworker_start_ns\x18\x04 \x01(\x04\x12\x15\n\rworker_end_ns\x18\x05 \x01(\x04\x12\x1b\n\x0e\x64ispatch_token\x18\x06 \x01(\tH\x00\x88\x01\x01\x12:\n\x07\x63ontrol\x18\x07 \x01(\x0b\x32$.rappel.messages.WorkflowNodeControlH\x01\x88\x01\x01\x42\x11\n\x0f_dispatch_tokenB\n\n\x08_control\" \n\x03\x41\x63k\x12\x19\n\x11\x61\x63ked_delivery_id\x18\x01 \x01(\x04\" \n\x0bWorkerHello\x12\x11\n\tworker_id\x18\x01 \x01(\x04\"\xc8\x04\n\x0fWorkflowDagNode\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\t\x12<\n\x06kwargs\x18\x03 \x03(\x0b\x32,.rappel.messages.WorkflowDagNode.KwargsEntry\x12\x12\n\ndepends_on\x18\x04 \x03(\t\x12\x15\n\rwait_for_sync\x18\x05 \x03(\t\x12\x10\n\x08produces\x18\x06 \x03(\t\x12\x0e\n\x06module\x18\x07 \x01(\t\x12\r\n\x05guard\x18\x08 \x01(\t\x12?\n\x0f\x65xception_edges\x18\t \x03(\x0b\x32&.rappel.messages.WorkflowExceptionEdge\x12\x1c\n\x0ftimeout_seconds\x18\n \x01(\rH\x00\x88\x01\x01\x12\x18\n\x0bmax_retries\x18\x0b \x01(\rH\x01\x88\x01\x01\x12 \n\x13timeout_retry_limit\x18\x0c \x01(\rH\x02\x88\x01\x01\x12\x34\n\x04loop\x18\r \x01(\x0b\x32!.rappel.messages.WorkflowLoopSpecH\x03\x88\x01\x01\x12\x32\n\x03\x61st\x18\x0e \x01(\x0b\x32 .rappel.messages.WorkflowNodeAstH\x04\x88\x01\x01\x1a-\n\x0bKwargsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x12\n\x10_timeout_secondsB\x0e\n\x0c_max_retriesB\x16\n\x14_timeout_retry_limitB\x07\n\x05_loopB\x06\n\x04_ast\"u\n\x15WorkflowDagDefinition\x12\x12\n\nconcurrent\x18\x01 \x01(\x08\x12/\n\x05nodes\x18\x02 \x03(\x0b\x32 .rappel.messages.WorkflowDagNode\x12\x17\n\x0freturn_variable\x18\x03 \x01(\t\"a\n\x15WorkflowExceptionEdge\x12\x16\n\x0esource_node_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65xception_type\x18\x02 \x01(\t\x12\x18\n\x10\x65xception_module\x18\x03 \x01(\t\"\x87\x02\n\x10WorkflowLoopSpec\x12\x15\n\riterable_expr\x18\x01 \x01(\t\x12\x10\n\x08loop_var\x18\x02 \x01(\t\x12\x13\n\x0b\x61\x63\x63umulator\x18\x03 \x01(\t\x12\x10\n\x08preamble\x18\x04 \x01(\t\x12\x13\n\x0b\x62ody_action\x18\x05 \x01(\t\x12\x13\n\x0b\x62ody_module\x18\x06 \x01(\t\x12\x46\n\x0b\x62ody_kwargs\x18\x07 \x03(\x0b\x32\x31.rappel.messages.WorkflowLoopSpec.BodyKwargsEntry\x1a\x31\n\x0f\x42odyKwargsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa4\x01\n\x13WorkflowLoopControl\x12\x0f\n\x07node_id\x18\x01 \x01(\t\x12\x12\n\nnext_index\x18\x02 \x01(\r\x12\x10\n\x08has_next\x18\x03 \x01(\x08\x12\x13\n\x0b\x61\x63\x63umulator\x18\x04 \x01(\t\x12\x41\n\x11\x61\x63\x63umulator_value\x18\x05 \x01(\x0b\x32&.rappel.messages.WorkflowArgumentValue\"S\n\x13WorkflowNodeControl\x12\x34\n\x04loop\x18\x01 \x01(\x0b\x32$.rappel.messages.WorkflowLoopControlH\x00\x42\x06\n\x04kind\"\x80\x02\n\x0fWorkflowNodeAst\x12<\n\x06kwargs\x18\x01 \x03(\x0b\x32,.rappel.messages.WorkflowNodeAst.KwargsEntry\x12)\n\x05guard\x18\x02 \x01(\x0b\x32\x15.rappel.messages.ExprH\x00\x88\x01\x01\x12+\n\x04loop\x18\x03 \x01(\x0b\x32\x18.rappel.messages.LoopAstH\x01\x88\x01\x01\x1a\x44\n\x0bKwargsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.rappel.messages.Expr:\x02\x38\x01\x42\x08\n\x06_guardB\x07\n\x05_loop\"\xb3\x01\n\x07LoopAst\x12\'\n\x08iterable\x18\x01 \x01(\x0b\x32\x15.rappel.messages.Expr\x12\x10\n\x08loop_var\x18\x02 \x01(\t\x12\x13\n\x0b\x61\x63\x63umulator\x18\x03 \x01(\t\x12\'\n\x08preamble\x18\x04 \x03(\x0b\x32\x15.rappel.messages.Stmt\x12/\n\x0b\x62ody_action\x18\x05 \x01(\x0b\x32\x1a.rappel.messages.ActionAst\"a\n\tActionAst\x12\x13\n\x0b\x61\x63tion_name\x18\x01 \x01(\t\x12\x13\n\x0bmodule_name\x18\x02 \x01(\t\x12*\n\x08keywords\x18\x03 \x03(\x0b\x32\x18.rappel.messages.Keyword\"<\n\x07Keyword\x12\x0b\n\x03\x61rg\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.rappel.messages.Expr\"`\n\x04Stmt\x12)\n\x06\x61ssign\x18\x01 \x01(\x0b\x32\x17.rappel.messages.AssignH\x00\x12%\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x15.rappel.messages.ExprH\x00\x42\x06\n\x04kind\"V\n\x06\x41ssign\x12&\n\x07targets\x18\x01 \x03(\x0b\x32\x15.rappel.messages.Expr\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.rappel.messages.Expr\"\x95\x04\n\x04\x45xpr\x12%\n\x04name\x18\x01 \x01(\x0b\x32\x15.rappel.messages.NameH\x00\x12-\n\x08\x63onstant\x18\x02 \x01(\x0b\x32\x19.rappel.messages.ConstantH\x00\x12/\n\tattribute\x18\x03 \x01(\x0b\x32\x1a.rappel.messages.AttributeH\x00\x12/\n\tsubscript\x18\x04 \x01(\x0b\x32\x1a.rappel.messages.SubscriptH\x00\x12(\n\x06\x62in_op\x18\x05 \x01(\x0b\x32\x16.rappel.messages.BinOpH\x00\x12*\n\x07\x62ool_op\x18\x06 \x01(\x0b\x32\x17.rappel.messages.BoolOpH\x00\x12+\n\x07\x63ompare\x18\x07 \x01(\x0b\x32\x18.rappel.messages.CompareH\x00\x12%\n\x04\x63\x61ll\x18\x08 \x01(\x0b\x32\x15.rappel.messages.CallH\x00\x12%\n\x04list\x18\t \x01(\x0b\x32\x15.rappel.messages.ListH\x00\x12\'\n\x05tuple\x18\n \x01(\x0b\x32\x16.rappel.messages.TupleH\x00\x12%\n\x04\x64ict\x18\x0b \x01(\x0b\x32\x15.rappel.messages.DictH\x00\x12,\n\x08unary_op\x18\x0c \x01(\x0b\x32\x18.rappel.messages.UnaryOpH\x00\x42\x06\n\x04kind\"\x12\n\x04Name\x12\n\n\x02id\x18\x01 \x01(\t\"\x80\x01\n\x08\x43onstant\x12\x16\n\x0cstring_value\x18\x01 \x01(\tH\x00\x12\x15\n\x0b\x66loat_value\x18\x02 \x01(\x01H\x00\x12\x13\n\tint_value\x18\x03 \x01(\x12H\x00\x12\x14\n\nbool_value\x18\x04 \x01(\x08H\x00\x12\x11\n\x07is_none\x18\x05 \x01(\x08H\x00\x42\x07\n\x05value\"?\n\tAttribute\x12$\n\x05value\x18\x01 \x01(\x0b\x32\x15.rappel.messages.Expr\x12\x0c\n\x04\x61ttr\x18\x02 \x01(\t\"W\n\tSubscript\x12$\n\x05value\x18\x01 \x01(\x0b\x32\x15.rappel.messages.Expr\x12$\n\x05slice\x18\x02 \x01(\x0b\x32\x15.rappel.messages.Expr\"z\n\x05\x42inOp\x12#\n\x04left\x18\x01 \x01(\x0b\x32\x15.rappel.messages.Expr\x12&\n\x02op\x18\x02 \x01(\x0e\x32\x1a.rappel.messages.BinOpKind\x12$\n\x05right\x18\x03 \x01(\x0b\x32\x15.rappel.messages.Expr\"X\n\x06\x42oolOp\x12\'\n\x02op\x18\x01 \x01(\x0e\x32\x1b.rappel.messages.BoolOpKind\x12%\n\x06values\x18\x02 \x03(\x0b\x32\x15.rappel.messages.Expr\"\x83\x01\n\x07\x43ompare\x12#\n\x04left\x18\x01 \x01(\x0b\x32\x15.rappel.messages.Expr\x12\'\n\x03ops\x18\x02 \x03(\x0e\x32\x1a.rappel.messages.CmpOpKind\x12*\n\x0b\x63omparators\x18\x03 \x03(\x0b\x32\x15.rappel.messages.Expr\"|\n\x04\x43\x61ll\x12#\n\x04\x66unc\x18\x01 \x01(\x0b\x32\x15.rappel.messages.Expr\x12#\n\x04\x61rgs\x18\x02 \x03(\x0b\x32\x15.rappel.messages.Expr\x12*\n\x08keywords\x18\x03 \x03(\x0b\x32\x18.rappel.messages.Keyword\"[\n\x07UnaryOp\x12(\n\x02op\x18\x01 \x01(\x0e\x32\x1c.rappel.messages.UnaryOpKind\x12&\n\x07operand\x18\x02 \x01(\x0b\x32\x15.rappel.messages.Expr\"+\n\x04List\x12#\n\x04\x65lts\x18\x01 \x03(\x0b\x32\x15.rappel.messages.Expr\",\n\x05Tuple\x12#\n\x04\x65lts\x18\x01 \x03(\x0b\x32\x15.rappel.messages.Expr\"R\n\x04\x44ict\x12#\n\x04keys\x18\x01 \x03(\x0b\x32\x15.rappel.messages.Expr\x12%\n\x06values\x18\x02 \x03(\x0b\x32\x15.rappel.messages.Expr\"\xb1\x01\n\x14WorkflowRegistration\x12\x15\n\rworkflow_name\x18\x01 \x01(\t\x12\x33\n\x03\x64\x61g\x18\x02 \x01(\x0b\x32&.rappel.messages.WorkflowDagDefinition\x12\x10\n\x08\x64\x61g_hash\x18\x03 \x01(\t\x12;\n\x0finitial_context\x18\x04 \x01(\x0b\x32\".rappel.messages.WorkflowArguments\"v\n\x13WorkflowNodeContext\x12\x10\n\x08variable\x18\x01 \x01(\t\x12\x33\n\x07payload\x18\x02 \x01(\x0b\x32\".rappel.messages.WorkflowArguments\x12\x18\n\x10workflow_node_id\x18\x03 \x01(\t\"\x94\x03\n\x15WorkflowArgumentValue\x12?\n\tprimitive\x18\x01 \x01(\x0b\x32*.rappel.messages.PrimitiveWorkflowArgumentH\x00\x12?\n\tbasemodel\x18\x02 \x01(\x0b\x32*.rappel.messages.BaseModelWorkflowArgumentH\x00\x12\x38\n\texception\x18\x03 \x01(\x0b\x32#.rappel.messages.WorkflowErrorValueH\x00\x12;\n\nlist_value\x18\x04 \x01(\x0b\x32%.rappel.messages.WorkflowListArgumentH\x00\x12=\n\x0btuple_value\x18\x05 \x01(\x0b\x32&.rappel.messages.WorkflowTupleArgumentH\x00\x12;\n\ndict_value\x18\x06 \x01(\x0b\x32%.rappel.messages.WorkflowDictArgumentH\x00\x42\x06\n\x04kind\"V\n\x10WorkflowArgument\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32&.rappel.messages.WorkflowArgumentValue\"I\n\x11WorkflowArguments\x12\x34\n\targuments\x18\x01 \x03(\x0b\x32!.rappel.messages.WorkflowArgument\"\xb0\x01\n\x19PrimitiveWorkflowArgument\x12\x16\n\x0cstring_value\x18\x01 \x01(\tH\x00\x12\x16\n\x0c\x64ouble_value\x18\x02 \x01(\x01H\x00\x12\x13\n\tint_value\x18\x03 \x01(\x12H\x00\x12\x14\n\nbool_value\x18\x04 \x01(\x08H\x00\x12\x30\n\nnull_value\x18\x05 \x01(\x0e\x32\x1a.google.protobuf.NullValueH\x00\x42\x06\n\x04kind\"n\n\x19\x42\x61seModelWorkflowArgument\x12\x0e\n\x06module\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x33\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32%.rappel.messages.WorkflowDictArgument\"V\n\x12WorkflowErrorValue\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06module\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x11\n\ttraceback\x18\x04 \x01(\t\"M\n\x14WorkflowListArgument\x12\x35\n\x05items\x18\x01 \x03(\x0b\x32&.rappel.messages.WorkflowArgumentValue\"N\n\x15WorkflowTupleArgument\x12\x35\n\x05items\x18\x01 \x03(\x0b\x32&.rappel.messages.WorkflowArgumentValue\"J\n\x14WorkflowDictArgument\x12\x32\n\x07\x65ntries\x18\x01 \x03(\x0b\x32!.rappel.messages.WorkflowArgument\"\xf6\x01\n\x14WorkflowNodeDispatch\x12.\n\x04node\x18\x01 \x01(\x0b\x32 .rappel.messages.WorkflowDagNode\x12:\n\x0eworkflow_input\x18\x02 \x01(\x0b\x32\".rappel.messages.WorkflowArguments\x12\x35\n\x07\x63ontext\x18\x03 \x03(\x0b\x32$.rappel.messages.WorkflowNodeContext\x12;\n\x0fresolved_kwargs\x18\x04 \x01(\x0b\x32\".rappel.messages.WorkflowArguments\"\\\n\x17RegisterWorkflowRequest\x12;\n\x0cregistration\x18\x02 \x01(\x0b\x32%.rappel.messages.WorkflowRegistrationJ\x04\x08\x01\x10\x02\"U\n\x18RegisterWorkflowResponse\x12\x1b\n\x13workflow_version_id\x18\x01 \x01(\t\x12\x1c\n\x14workflow_instance_id\x18\x02 \x01(\t\"I\n\x16WaitForInstanceRequest\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\x12\x1a\n\x12poll_interval_secs\x18\x02 \x01(\x01\"*\n\x17WaitForInstanceResponse\x12\x0f\n\x07payload\x18\x01 \x01(\x0c*\xbe\x01\n\x0bMessageKind\x12\x1c\n\x18MESSAGE_KIND_UNSPECIFIED\x10\x00\x12 \n\x1cMESSAGE_KIND_ACTION_DISPATCH\x10\x01\x12\x1e\n\x1aMESSAGE_KIND_ACTION_RESULT\x10\x02\x12\x14\n\x10MESSAGE_KIND_ACK\x10\x03\x12\x1a\n\x16MESSAGE_KIND_HEARTBEAT\x10\x04\x12\x1d\n\x19MESSAGE_KIND_WORKER_HELLO\x10\x05*\xc1\x01\n\tBinOpKind\x12\x1b\n\x17\x42IN_OP_KIND_UNSPECIFIED\x10\x00\x12\x13\n\x0f\x42IN_OP_KIND_ADD\x10\x01\x12\x13\n\x0f\x42IN_OP_KIND_SUB\x10\x02\x12\x14\n\x10\x42IN_OP_KIND_MULT\x10\x03\x12\x13\n\x0f\x42IN_OP_KIND_DIV\x10\x04\x12\x13\n\x0f\x42IN_OP_KIND_MOD\x10\x05\x12\x18\n\x14\x42IN_OP_KIND_FLOORDIV\x10\x06\x12\x13\n\x0f\x42IN_OP_KIND_POW\x10\x07*U\n\nBoolOpKind\x12\x1c\n\x18\x42OOL_OP_KIND_UNSPECIFIED\x10\x00\x12\x14\n\x10\x42OOL_OP_KIND_AND\x10\x01\x12\x13\n\x0f\x42OOL_OP_KIND_OR\x10\x02*\x80\x02\n\tCmpOpKind\x12\x1b\n\x17\x43MP_OP_KIND_UNSPECIFIED\x10\x00\x12\x12\n\x0e\x43MP_OP_KIND_EQ\x10\x01\x12\x16\n\x12\x43MP_OP_KIND_NOT_EQ\x10\x02\x12\x12\n\x0e\x43MP_OP_KIND_LT\x10\x03\x12\x14\n\x10\x43MP_OP_KIND_LT_E\x10\x04\x12\x12\n\x0e\x43MP_OP_KIND_GT\x10\x05\x12\x14\n\x10\x43MP_OP_KIND_GT_E\x10\x06\x12\x12\n\x0e\x43MP_OP_KIND_IN\x10\x07\x12\x16\n\x12\x43MP_OP_KIND_NOT_IN\x10\x08\x12\x12\n\x0e\x43MP_OP_KIND_IS\x10\t\x12\x16\n\x12\x43MP_OP_KIND_IS_NOT\x10\n*s\n\x0bUnaryOpKind\x12\x1d\n\x19UNARY_OP_KIND_UNSPECIFIED\x10\x00\x12\x16\n\x12UNARY_OP_KIND_USUB\x10\x01\x12\x16\n\x12UNARY_OP_KIND_UADD\x10\x02\x12\x15\n\x11UNARY_OP_KIND_NOT\x10\x03\x32\xe0\x01\n\x0fWorkflowService\x12g\n\x10RegisterWorkflow\x12(.rappel.messages.RegisterWorkflowRequest\x1a).rappel.messages.RegisterWorkflowResponse\x12\x64\n\x0fWaitForInstance\x12\'.rappel.messages.WaitForInstanceRequest\x1a(.rappel.messages.WaitForInstanceResponse2R\n\x0cWorkerBridge\x12\x42\n\x06\x41ttach\x12\x19.rappel.messages.Envelope\x1a\x19.rappel.messages.Envelope(\x01\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'messages_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_WORKFLOWDAGNODE_KWARGSENTRY']._loaded_options = None
  _globals['_WORKFLOWDAGNODE_KWARGSENTRY']._serialized_options = b'8\001'
  _globals['_WORKFLOWLOOPSPEC_BODYKWARGSENTRY']._loaded_options = None
  _globals['_WORKFLOWLOOPSPEC_BODYKWARGSENTRY']._serialized_options = b'8\001'
  _globals['_WORKFLOWNODEAST_KWARGSENTRY']._loaded_options = None
  _globals['_WORKFLOWNODEAST_KWARGSENTRY']._serialized_options = b'8\001'
  _globals['_MESSAGEKIND']._serialized_start=6573
  _globals['_MESSAGEKIND']._serialized_end=6763
  _globals['_BINOPKIND']._serialized_start=6766
  _globals['_BINOPKIND']._serialized_end=6959
  _globals['_BOOLOPKIND']._serialized_start=6961
  _globals['_BOOLOPKIND']._serialized_end=7046
  _globals['_CMPOPKIND']._serialized_start=7049
  _globals['_CMPOPKIND']._serialized_end=7305
  _globals['_UNARYOPKIND']._serialized_start=7307
  _globals['_UNARYOPKIND']._serialized_end=7422
  _globals['_ENVELOPE']._serialized_start=65
  _globals['_ENVELOPE']._serialized_end=179
  _globals['_ACTIONDISPATCH']._serialized_start=182
  _globals['_ACTIONDISPATCH']._serialized_end=501
  _globals['_ACTIONRESULT']._serialized_start=504
  _globals['_ACTIONRESULT']._serialized_end=775
  _globals['_ACK']._serialized_start=777
  _globals['_ACK']._serialized_end=809
  _globals['_WORKERHELLO']._serialized_start=811
  _globals['_WORKERHELLO']._serialized_end=843
  _globals['_WORKFLOWDAGNODE']._serialized_start=846
  _globals['_WORKFLOWDAGNODE']._serialized_end=1430
  _globals['_WORKFLOWDAGNODE_KWARGSENTRY']._serialized_start=1308
  _globals['_WORKFLOWDAGNODE_KWARGSENTRY']._serialized_end=1353
  _globals['_WORKFLOWDAGDEFINITION']._serialized_start=1432
  _globals['_WORKFLOWDAGDEFINITION']._serialized_end=1549
  _globals['_WORKFLOWEXCEPTIONEDGE']._serialized_start=1551
  _globals['_WORKFLOWEXCEPTIONEDGE']._serialized_end=1648
  _globals['_WORKFLOWLOOPSPEC']._serialized_start=1651
  _globals['_WORKFLOWLOOPSPEC']._serialized_end=1914
  _globals['_WORKFLOWLOOPSPEC_BODYKWARGSENTRY']._serialized_start=1865
  _globals['_WORKFLOWLOOPSPEC_BODYKWARGSENTRY']._serialized_end=1914
  _globals['_WORKFLOWLOOPCONTROL']._serialized_start=1917
  _globals['_WORKFLOWLOOPCONTROL']._serialized_end=2081
  _globals['_WORKFLOWNODECONTROL']._serialized_start=2083
  _globals['_WORKFLOWNODECONTROL']._serialized_end=2166
  _globals['_WORKFLOWNODEAST']._serialized_start=2169
  _globals['_WORKFLOWNODEAST']._serialized_end=2425
  _globals['_WORKFLOWNODEAST_KWARGSENTRY']._serialized_start=2338
  _globals['_WORKFLOWNODEAST_KWARGSENTRY']._serialized_end=2406
  _globals['_LOOPAST']._serialized_start=2428
  _globals['_LOOPAST']._serialized_end=2607
  _globals['_ACTIONAST']._serialized_start=2609
  _globals['_ACTIONAST']._serialized_end=2706
  _globals['_KEYWORD']._serialized_start=2708
  _globals['_KEYWORD']._serialized_end=2768
  _globals['_STMT']._serialized_start=2770
  _globals['_STMT']._serialized_end=2866
  _globals['_ASSIGN']._serialized_start=2868
  _globals['_ASSIGN']._serialized_end=2954
  _globals['_EXPR']._serialized_start=2957
  _globals['_EXPR']._serialized_end=3490
  _globals['_NAME']._serialized_start=3492
  _globals['_NAME']._serialized_end=3510
  _globals['_CONSTANT']._serialized_start=3513
  _globals['_CONSTANT']._serialized_end=3641
  _globals['_ATTRIBUTE']._serialized_start=3643
  _globals['_ATTRIBUTE']._serialized_end=3706
  _globals['_SUBSCRIPT']._serialized_start=3708
  _globals['_SUBSCRIPT']._serialized_end=3795
  _globals['_BINOP']._serialized_start=3797
  _globals['_BINOP']._serialized_end=3919
  _globals['_BOOLOP']._serialized_start=3921
  _globals['_BOOLOP']._serialized_end=4009
  _globals['_COMPARE']._serialized_start=4012
  _globals['_COMPARE']._serialized_end=4143
  _globals['_CALL']._serialized_start=4145
  _globals['_CALL']._serialized_end=4269
  _globals['_UNARYOP']._serialized_start=4271
  _globals['_UNARYOP']._serialized_end=4362
  _globals['_LIST']._serialized_start=4364
  _globals['_LIST']._serialized_end=4407
  _globals['_TUPLE']._serialized_start=4409
  _globals['_TUPLE']._serialized_end=4453
  _globals['_DICT']._serialized_start=4455
  _globals['_DICT']._serialized_end=4537
  _globals['_WORKFLOWREGISTRATION']._serialized_start=4540
  _globals['_WORKFLOWREGISTRATION']._serialized_end=4717
  _globals['_WORKFLOWNODECONTEXT']._serialized_start=4719
  _globals['_WORKFLOWNODECONTEXT']._serialized_end=4837
  _globals['_WORKFLOWARGUMENTVALUE']._serialized_start=4840
  _globals['_WORKFLOWARGUMENTVALUE']._serialized_end=5244
  _globals['_WORKFLOWARGUMENT']._serialized_start=5246
  _globals['_WORKFLOWARGUMENT']._serialized_end=5332
  _globals['_WORKFLOWARGUMENTS']._serialized_start=5334
  _globals['_WORKFLOWARGUMENTS']._serialized_end=5407
  _globals['_PRIMITIVEWORKFLOWARGUMENT']._serialized_start=5410
  _globals['_PRIMITIVEWORKFLOWARGUMENT']._serialized_end=5586
  _globals['_BASEMODELWORKFLOWARGUMENT']._serialized_start=5588
  _globals['_BASEMODELWORKFLOWARGUMENT']._serialized_end=5698
  _globals['_WORKFLOWERRORVALUE']._serialized_start=5700
  _globals['_WORKFLOWERRORVALUE']._serialized_end=5786
  _globals['_WORKFLOWLISTARGUMENT']._serialized_start=5788
  _globals['_WORKFLOWLISTARGUMENT']._serialized_end=5865
  _globals['_WORKFLOWTUPLEARGUMENT']._serialized_start=5867
  _globals['_WORKFLOWTUPLEARGUMENT']._serialized_end=5945
  _globals['_WORKFLOWDICTARGUMENT']._serialized_start=5947
  _globals['_WORKFLOWDICTARGUMENT']._serialized_end=6021
  _globals['_WORKFLOWNODEDISPATCH']._serialized_start=6024
  _globals['_WORKFLOWNODEDISPATCH']._serialized_end=6270
  _globals['_REGISTERWORKFLOWREQUEST']._serialized_start=6272
  _globals['_REGISTERWORKFLOWREQUEST']._serialized_end=6364
  _globals['_REGISTERWORKFLOWRESPONSE']._serialized_start=6366
  _globals['_REGISTERWORKFLOWRESPONSE']._serialized_end=6451
  _globals['_WAITFORINSTANCEREQUEST']._serialized_start=6453
  _globals['_WAITFORINSTANCEREQUEST']._serialized_end=6526
  _globals['_WAITFORINSTANCERESPONSE']._serialized_start=6528
  _globals['_WAITFORINSTANCERESPONSE']._serialized_end=6570
  _globals['_WORKFLOWSERVICE']._serialized_start=7425
  _globals['_WORKFLOWSERVICE']._serialized_end=7649
  _globals['_WORKERBRIDGE']._serialized_start=7651
  _globals['_WORKERBRIDGE']._serialized_end=7733
# @@protoc_insertion_point(module_scope)
